@@ -1,8 +1,7 @@
-// channels.h - written and placed in the public domain by Wei Dai
+// channels.h - originally written and placed in the public domain by Wei Dai
 
-//! \file
-//! \headerfile channels.h
-//! \brief Classes for multiple named channels
+/// \file channels.h
+/// \brief Classes for multiple named channels
 
 #ifndef CRYPTOPP_CHANNELS_H
 #define CRYPTOPP_CHANNELS_H
@@ -12,10 +11,15 @@
 #include "smartptr.h"
 #include "stdcpp.h"
 
+#if CRYPTOPP_MSC_VERSION
+# pragma warning(push)
+# pragma warning(disable: 4355)
+#endif
+
 NAMESPACE_BEGIN(CryptoPP)
 
 #if 0
-//! Route input on default channel to different and/or multiple channels based on message sequence number
+/// Route input on default channel to different and/or multiple channels based on message sequence number
 class MessageSwitch : public Sink
 {
 public:
@@ -88,7 +92,7 @@ protected:
 	ChannelRouteIterator();
 };
 
-//! Route input to different and/or multiple channels based on channel ID
+/// Route input to different and/or multiple channels based on channel ID
 class CRYPTOPP_DLL ChannelSwitch : public Multichannel<Sink>, public ChannelSwitchTypedefs
 {
 public:
@@ -131,4 +135,8 @@ private:
 
 NAMESPACE_END
 
+#if CRYPTOPP_MSC_VERSION
+# pragma warning(pop)
+#endif
+
 #endif
